@@ -12,7 +12,7 @@ sub create_all {
 	my $default_menu_def = Kephra::Config::File::load($default_file);
 	unless ($default_menu_def) {
 		require Kephra::Config::Embedded;
-		$default_menu_def = Kephra::Config::Embedded::get_contextmenus();
+		$default_menu_def = Kephra::Config::Embedded::contextmenus();
 	}
 
 	for my $menu_id (keys %{$config->{id}}){
